import os
import click
from flask import Flask

def create_app():
    app = Flask(__name__)

    @app.route('/')
    def index():
        return 'Namaste Duniya! This is a Flask app generated by Flask-Wiz.'

    return app

@click.group()
def cli():
    pass

@cli.command()
def new():
    # Prompt user for project name
    name = click.prompt('Enter project name')

    # Prompt user for database system
    db_options = ['mongodb', 'sqlite', 'mysql', 'postgresql']
    db = click.prompt('Select database system', type=click.Choice(db_options))

    # Additional setup code for the new project (e.g., creating files, folders, etc.)
    os.makedirs(name)
    os.chdir(name)

    # Create directories for templates and static files
    os.makedirs('templates')
    os.makedirs('static')

    with open('.gitignore', 'w') as gitignore_file:
        gitignore_file.write("# Default .gitignore for Flask project\n")
        gitignore_file.write("venv/\n")
        gitignore_file.write("__pycache__/\n")
        gitignore_file.write(".vscode/\n")
        # Add more entries as needed

    with open('.env', 'w') as env_file:
        env_file.write("# Default .env file for Flask project\n")
        # Add default environment variables if needed

    with open('app.py', 'w') as app_file:
        if db == 'mongodb':
            app_file.write(
                """from flask import Flask
from pymongo import MongoClient

app = Flask(__name__)
client = MongoClient('mongodb://localhost:27017/')
db = client['my_database']

@app.route('/')
def index():
    return 'Namaste Duniya! This is a Flask app generated by Flask-Wiz for MongoDB.'

if __name__ == '__main__':
    app.run()
""")
        elif db == 'sqlite':
            app_file.write(
                """from flask import Flask
import sqlite3

app = Flask(__name__)
conn = sqlite3.connect('database.db')

@app.route('/')
def index():
    return 'Namaste Duniya! This is a Flask app generated by Flask-Wiz for SQLite.'

if __name__ == '__main__':
    app.run()
""")
        elif db == 'mysql':
            app_file.write(
                """from flask import Flask
import pymysql

app = Flask(__name__)
conn = pymysql.connect(host='localhost', user='root', password='', database='my_database')

@app.route('/')
def index():
    return 'Namaste Duniya! This is a Flask app generated by Flask-Wiz MySQL.'

if __name__ == '__main__':
    app.run()
""")
        elif db == 'postgresql':
            app_file.write(
                """from flask import Flask
import psycopg2

app = Flask(__name__)
conn = psycopg2.connect(host='localhost', user='postgres', password='', dbname='my_database')

@app.route('/')
def index():
    return 'Namaste Duniya! This is a Flask app generated by Flask-Wiz PostgreSQL.'

if __name__ == '__main__':
    app.run()
""")

    click.echo(f'New Flask project "{name}" created successfully with {db} database!')

if __name__ == '__main__':
    cli()
